<?php

namespace Drupal\address_checkout\Helper;

use Drupal\profile\Entity\Profile;

/**
 * Class AddressCheckoutHelper.
 *
 * @package Drupal\modules\address_checkout
 */
class AddressCheckoutHelper {

  /**
   * Keep class object.
   *
   * @var object
   */
  public static $helper = NULL;

  /**
   * Protected profiles variable.
   *
   * @var profiles
   */
  protected $profiles;

  /**
   * Protected container variable.
   *
   * @var container
   */
  protected $container;

  /**
   * Protected request variable.
   *
   * @var request
   */
  protected $request;

  /**
   * Private constructor to avoid instantiation.
   */
  private function __construct() {
    $this->container = \Drupal::getContainer();
    $this->profiles = Profile::loadMultiple();
    $this->request = \Drupal::request();
  }

  /**
   * Get class instance using this function.
   *
   * @return DomainRouteMetaHelper
   *   return Object.
   */
  public static function getInstance() {
    if (!self::$helper) {
      self::$helper = new AddressCheckoutHelper();
    }
    return self::$helper;
  }

  /**
   * Ajax add to cart Form.
   *
   * @param string $form_id
   *   Form id.
   * @param array $form
   *   Form array.
   * @param array $form_state
   *   Form State.
   */
  public function ajaxGetAddress($form_id, &$form, &$form_state) {
    if (strstr($this->request->getUri(), 'order_information')) {
      foreach ($this->profiles as $key => $value) {
        if (isset($value)) {
          $profileType = $value->get('type')->getValue()[0]['target_id'];
          $profiles = $this->container->get('entity_type.manager')
            ->getStorage('profile')->loadMultipleByUser($this->container
            ->get('current_user'), $profileType);
        }
      }
      $profilesData = [];

      foreach ($profiles as $key => $value) {
        $profilesData[$key] = $value->get('address')->getString();
      }
      $form['#prefix'] = '<div id="modal_ajax_form">';
      $form['#suffix'] = '</div>';
      $defaultValue = $this->request->get('id');
      // Check default value.
      if ($defaultValue) {
        // Load Profile.
        $profile = Profile::load($defaultValue);
        // Check profile if exists else provide default value.
        if ($profile) {
          $form['payment_information']['billing_information']['#default_value'] = $profile;
        }
        else {
          $defaultValue = 0;
        }
      }
      else {
        $defaultValue = 0;
      }
      // Attach dialog library.
      $form['#attached']['library'][] = 'core/drupal.dialog.ajax';
      $profilesData[0] = 'New Address';
      $form['address_list'] = [
        '#type' => 'radios',
        '#title' => t('Saved Addresses'),
        '#options' => $profilesData,
        '#weight' => -100,
        '#default_value' => $defaultValue,
        '#ajax' => [
          'callback' => 'address_checkout_callback',
          'event' => 'click',
          'wrapper' => 'modal_ajax_form',
          'arguments' => [$form, $form_state],
          'progress' => [
            'type' => 'throbber',
            'message' => 'Processing',
          ],
        ],
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getCurrentStep($steps, $step_id) {
    $current_index = array_key_exists($step_id, $steps);
    return $current_index == TRUE ? $step_id : NULL;
  }

}
